@@ -8,11 +8,12 @@
 from formatter import *
 from shell import *
 from irc import *
+from nuts import *
 
 import PIL
-import collections
+from collections import Sequence
 
-VERSION = "1.3"
+VERSION = "1.4"
 
 def scale(image, width, height):
     """
@@ -41,7 +42,7 @@ def ensure_rgb(palette, pixel):
     Return the an rgb tuple for pixel, look it up in palette if
     necessary.
     """
-    if isinstance(pixel, collections.Sequence):
+    if isinstance(pixel, Sequence):
         return pixel[:3]
     else:
         return palette_lookup(palette, pixel)
